==> bonita-server-6.1.0-sources.jar: org/bonitasoft/engine/core/process/instance/model/builder/event/handling/impl/SWaitingEventLogBuilderImpl.java <==
/**
 * Copyright (C) 2012-2013 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.core.process.instance.model.builder.event.handling.impl;

import org.bonitasoft.engine.core.process.instance.model.builder.event.handling.SWaitingEventLogBuilder;
import org.bonitasoft.engine.queriablelogger.model.SQueriableLog;
import org.bonitasoft.engine.queriablelogger.model.builder.SPersistenceLogBuilder;
import org.bonitasoft.engine.queriablelogger.model.builder.impl.CRUDELogBuilder;
import org.bonitasoft.engine.queriablelogger.model.builder.impl.MissingMandatoryFieldsException;

/**
 * @author Elias Ricken de Medeiros
 * @author Matthieu Chaffotte
 */
public class SWaitingEventLogBuilderImpl extends CRUDELogBuilder implements SWaitingEventLogBuilder {

    private static final String EVENT_INSTANCE_TRIGGER = "EVENT_INSTANCE_TRIGGER";

    public static final int EVENT_TRIGGER_INSTANCE_ID_INDEX = 2;

    public static final String EVENT_TRIGGER_INSTANCE_ID_KEY = "numericIndex3";

    @Override
    public SPersistenceLogBuilder objectId(final long objectId) {
        queriableLogBuilder.numericIndex(EVENT_TRIGGER_INSTANCE_ID_INDEX, objectId);
        return this;
    }

    @Override
    public String getObjectIdKey() {
        return EVENT_TRIGGER_INSTANCE_ID_KEY;
    }

    @Override
    protected String getActionTypePrefix() {
        return EVENT_INSTANCE_TRIGGER;
    }

    @Override
    protected void checkExtraRules(final SQueriableLog log) {
        if (log.getActionStatus() != SQueriableLog.STATUS_FAIL) {
            if (log.getNumericIndex(EVENT_TRIGGER_INSTANCE_ID_INDEX) == 0L) {
                throw new MissingMandatoryFieldsException("Some mandatory fields are missing: " + "Event Trigger Instance Id");
            }
        }

    }

}

==> bonita-server-6.4.1-sources.jar: org/bonitasoft/engine/core/process/instance/model/builder/event/handling/impl/SWaitingEventLogBuilderImpl.java <==
/**
 * Copyright (C) 2012-2013 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.core.process.instance.model.builder.event.handling.impl;

import org.bonitasoft.engine.core.process.instance.model.builder.event.handling.SWaitingEventLogBuilder;
import org.bonitasoft.engine.queriablelogger.model.SQueriableLog;
import org.bonitasoft.engine.queriablelogger.model.builder.SPersistenceLogBuilder;
import org.bonitasoft.engine.queriablelogger.model.builder.impl.CRUDELogBuilder;
import org.bonitasoft.engine.queriablelogger.model.builder.impl.MissingMandatoryFieldsException;

/**
 * @author Elias Ricken de Medeiros
 * @author Matthieu Chaffotte
 */
public class SWaitingEventLogBuilderImpl extends CRUDELogBuilder implements SWaitingEventLogBuilder {

    private static final String EVENT_INSTANCE_TRIGGER = "EVENT_INSTANCE_TRIGGER";

    @Override
    public SPersistenceLogBuilder objectId(final long objectId) {
        queriableLogBuilder.numericIndex(SWaitingEventLogBuilderFactoryImpl.EVENT_TRIGGER_INSTANCE_ID_INDEX, objectId);
        return this;
    }

    @Override
    protected String getActionTypePrefix() {
        return EVENT_INSTANCE_TRIGGER;
    }

    @Override
    protected void checkExtraRules(final SQueriableLog log) {
        if (log.getActionStatus() != SQueriableLog.STATUS_FAIL) {
            if (log.getNumericIndex(SWaitingEventLogBuilderFactoryImpl.EVENT_TRIGGER_INSTANCE_ID_INDEX) == 0L) {
                throw new MissingMandatoryFieldsException("Some mandatory fields are missing: " + "Event Trigger Instance Id");
            }
        }

    }

}
